'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _TrackList = require('./TrackList');

var _TrackList2 = _interopRequireDefault(_TrackList);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var SpotifyPlayer = _react2.default.createClass({
	displayName: 'SpotifyPlayer',

	getInitialState: function getInitialState() {
		return {
			albumData: null,
			playerPlaceholder: '<i class="fa fa-spinner fa-spin"></i>',
			albumName: this.props.albumName,
			artistName: this.props.artistName
		};
	},
	getDefaultProps: function getDefaultProps() {
		return {
			noDataFoundText: 'No data found',
			previewWarningText: 'Only 20 seconds preview',
			onTrackPlayed: undefined,
			onTrackPaused: undefined
		};
	},
	propTypes: {
		albumName: _react2.default.PropTypes.string.isRequired,
		artistName: _react2.default.PropTypes.string.isRequired,
		noDataFoundText: _react2.default.PropTypes.string,
		onTrackPlayed: _react2.default.PropTypes.func,
		onTrackPaused: _react2.default.PropTypes.func,
		previewWarningText: _react2.default.PropTypes.string
	},
	fetchAlbumData: function fetchAlbumData() {
		var that = this;
		var xhr = new XMLHttpRequest();
		var url = 'https://api.spotify.com/v1/search';
		var queryString = '?q=album:' + this.state.albumName + ' artist:' + this.state.artistName;
		queryString += '&type=album';
		xhr.open('get', url + queryString);
		xhr.onload = function () {
			var response = JSON.parse(xhr.responseText);
			if (response.albums.items.length > 0) {
				that.fetchTracks(response.albums.items[0].id, function (data) {
					if (data.tracks.items.length > 0) {
						that.setState({ albumData: data });
					} else {
						that.setState({ albumData: null, playerPlaceholder: that.props.noDataFoundText });
					}
				});
			} else {
				that.setState({ albumData: null, playerPlaceholder: that.props.noDataFoundText });
			}
		};
		xhr.onerror = function () {
			that.setState({ albumData: null, playerPlaceholder: that.props.noDataFoundText });
		};
		xhr.send();
	},
	fetchTracks: function fetchTracks(albumId, callback) {
		var xhr = new XMLHttpRequest();
		var that = this;
		xhr.open('get', 'https://api.spotify.com/v1/albums/' + albumId);
		xhr.onload = function () {
			var response = JSON.parse(xhr.responseText);
			callback(response);
		};
		xhr.onerror = function () {
			that.setState({ albumData: null, playerPlaceholder: that.props.noDataFoundText });
		};
		xhr.send();
	},
	firePlayingStatusChangeEvent: function firePlayingStatusChangeEvent(isPlaying, audioTrack, spotifyTrack) {
		if (isPlaying && this.props.onTrackPlayed) {
			this.props.onTrackPlayed(audioTrack, spotifyTrack);
		} else if (!isPlaying && this.props.onTrackPaused) {
			this.props.onTrackPaused(audioTrack, spotifyTrack);
		}
	},
	componentDidMount: function componentDidMount() {
		this.fetchAlbumData();
	},
	componentWillUpdate: function componentWillUpdate(newProps) {
		if (newProps.albumName !== this.props.albumName || newProps.artistName !== this.props.artistName) {
			this.setState({ artistName: newProps.artistName, albumName: newProps.albumName }, this.fetchAlbumData);
		}
	},
	render: function render() {
		var that = this;
		var playlistHeader = function playlistHeader() {
			if (that.props.showHeader) {
				return _react2.default.createElement(
					'div',
					{ className: 'media' },
					_react2.default.createElement(
						'div',
						{ className: 'media-left' },
						_react2.default.createElement(
							'a',
							{ href: that.state.albumData.external_urls.spotify },
							_react2.default.createElement('img', {
								alt: 'cover image',
								className: 'media-object',
								height: '64',
								src: that.state.albumData.images[0].url,
								width: '64'
							})
						)
					),
					_react2.default.createElement(
						'div',
						{ className: 'media-body' },
						_react2.default.createElement(
							'h4',
							{ className: 'media-heading' },
							that.state.albumData.name
						),
						that.state.albumData.release_date
					)
				);
			}
			return null;
		};
		if (this.state.albumData === null) {
			return _react2.default.createElement(
				'section',
				{ className: 'spotify-player' },
				_react2.default.createElement('div', { dangerouslySetInnerHTML: { __html: this.state.playerPlaceholder } })
			);
		} else {
			return _react2.default.createElement(
				'section',
				{ className: 'spotify-player' },
				playlistHeader(),
				_react2.default.createElement(_TrackList2.default, {
					previewWarningText: this.props.previewWarningText,
					tracks: this.state.albumData.tracks.items,
					updateTrackPlayingStatus: this.firePlayingStatusChangeEvent
				})
			);
		}
	}
});

module.exports = SpotifyPlayer;